import { BaseRespData } from '@/types/api'
import axios from './axios'
import {
  LogisticsMethod,
  LogisticsMethodList,
  UpdateLogisticsMethodStatus,
} from '@/types/api/logistics'
interface Ikey {
  [key: string]: unknown
}
interface ILogisticsParams {
  logType: 'logistics_way' | 'logistics_address'
  relaId: number | string
}
//获取日志
export function getLogisticsLog(params: ILogisticsParams) {
  return axios.get<never, BaseRespData<never>>('logisticsLog/getList', {
    params,
  })
}

/**
 * @description 物流方式
 */
//列表
export function getLogisticsWayList(data: LogisticsMethodList) {
  return axios.post<never, BaseRespData<never>>('/logisticsWay/list_page', data)
}
//新增
export function addLogisticsWay(data: LogisticsMethod) {
  return axios.post<Ikey, BaseRespData<never>>('/logisticsWay/add', data)
}
//修改
export function updateLogisticsWay(data: LogisticsMethod) {
  return axios.post<Ikey, BaseRespData<never>>('/logisticsWay/update', data)
}
//更新状态
export function updateStatusLogisticsWay(params: UpdateLogisticsMethodStatus) {
  return axios.get<Ikey, BaseRespData<never>>(
    '/logisticsWay/updateStatusById',
    {
      params,
    },
  )
}
// 删除
export function deleteLogisticsWay(ids: string) {
  return axios.get<Ikey, BaseRespData<never>>('/logisticsWay/delete', {
    params: { ids: ids },
  })
}
//获取申报规则列表
export function getRuleList() {
  return axios.get<never, BaseRespData<never>>(
    '/logisticsCustomsRule/getRuleList',
  )
}
//获取仓库列表
export function getWarehouseList() {
  return axios.get<never, BaseRespData<never>>('/factoryWarehouseInfo/getAll')
}
//获取平台列表
export function getPlatformList() {
  return axios.get<never, BaseRespData<never>>('/logisticsWay/platform')
}

/**
 * @description 发货地址
 */
//列表
export function getAddressByIdList(params: any) {
  return axios.get<never, BaseRespData<never>>('/logisticsAddress/list_page', {
    params,
  })
}
//根据id查询地址
export function getAddressById(params: any) {
  return axios.get<never, BaseRespData<never>>(
    '/logisticsAddress/getAddressById',
    {
      params,
    },
  )
}
//新增
export function addAddress(params: any) {
  return axios.post<never, BaseRespData<never>>(
    '/logisticsAddress/addAddress',
    params,
  )
}
//修改
export function updateAddress(params: any) {
  return axios.post<never, BaseRespData<never>>(
    '/logisticsAddress/updateAddress',
    params,
  )
}
//删除
export function deleteAddressByIds(params: any) {
  return axios.get<never, BaseRespData<never>>(
    '/logisticsAddress/deleteAddressByIds',
    {
      params,
    },
  )
}

/**
 * @description 物流报价
 */
//物流方式列表
export function getlogisticsWayAllList() {
  return axios.get<never, BaseRespData<never>>('/logisticsWay/all_list', {})
}
//物流报价列表
export function getlogisticsQuotationList() {
  return axios.get<never, BaseRespData<never>>(
    '/logistics/logisticsQuotation/list_page',
    {},
  )
}
//新增
export function addLogisticsQuotation(params: any) {
  return axios.get<never, BaseRespData<never>>(
    '/logistics/logisticsQuotation/add',
    params,
  )
}
//修改
export function updateLogisticsQuotation(params: any) {
  return axios.post<never, BaseRespData<never>>(
    '/logistics/logisticsQuotation/update',
    params,
  )
}
//删除
export function deleteLogisticsQuotation(params: any) {
  return axios.post<never, BaseRespData<never>>(
    '/logistics/logisticsQuotation/delete',
    params,
  )
}
//导入
export function importLogisticsQuotation(params: any) {
  return axios.get<never, BaseRespData<never>>(
    '/logistics/logisticsQuotation/import',
    { params },
  )
}
//下载模版
export function exportLogisticsQuotationTemplate(params: any) {
  return axios.get<never, BaseRespData<never>>(
    '/logistics/logisticsQuotation/exportExcel',
    { params },
  )
}
//根据ID查对象
export function getLogisticsQuotationByID(params: any) {
  return axios.get<never, BaseRespData<never>>(
    '/logistics/logisticsQuotation/get',
    { params },
  )
}

/**
 * @description 申报规则
 */
//列表
export function getLogisticsCustomsRuleList(params: any) {
  return axios.post<never, BaseRespData<never>>(
    '/logisticsCustomsRule/list_page',
    params,
  )
}
//新增
export function addLogisticsCustomsRule(params: any) {
  return axios.post<never, BaseRespData<never>>(
    '/logisticsCustomsRule/add',
    params,
  )
}
//修改
export function updateLogisticsCustomsRule(params: any) {
  return axios.post<never, BaseRespData<never>>(
    '/logisticsCustomsRule/update',
    params,
  )
}
//删除
export function deleteLogisticsCustomsRule(params: any) {
  return axios.get<never, BaseRespData<never>>('/logisticsCustomsRule/delete', {
    params,
  })
}
