import axios from '@/api/axios.ts'
import { BasePaginationData, BaseRespData } from '@/types/api'
import {
  warehouseSearchForm,
  InterWarehousePage,
  InterWarehouseTree,
  InterWarehouseDetail,
  InterskuList,
  InterWarehouseList,
  ILocation,
} from '@/types/api/warehouse'
export interface LogListData {
  createTime: string
  description: string
  createdTime?: string | null
}
export interface PrintData {
  code: string
  list: {
    locationName: string
    pickingLocation?: string
    skuName?: string
    warehouseSku?: string
    supplierItemNo?: string
    number?: string
  }[]
}
export interface factoryWarehouseInfo {
  pageSize: number
  currentPage: number
  total?: number
  warehouseId?: string
  locationName?: string
  remark?: string
  idList?: string | number[]
}

export interface ExportFactoryWarehouseInfo {
  pageSize?: number
  currentPage?: number
  total?: number
  warehouseId?: string
  locationName?: string
  remark?: string
  idList?: string | number[]
}

export interface WarehouseInventory {
  pageSize: number
  currentPage: number
  total?: number
  warehouseId: string
  skuName: string
  warehouseSku: string
  occupyInventory: string
  inventoryStart: string
  inventoryEnd: string
  productNumber: string
  freezeInventory: string
  inventory: string
  usableInventoryStart: string
  usableInventoryEnd: string
  occupyInventoryEnd: string
  occupyInventoryStart: string
}

export interface UpdateDefaulted {
  id?: number | string
  defaulted: number
}

export interface UpdateStatus {
  id?: number
  status: number | undefined
}

export interface warehouseInfo {
  id?: number | string
  name: string
  code: string
  sort: string
  defaulted: number
  factoryId?: number
  factoryCode?: string
  remarks: string
}

export interface WarehouseWarning {
  id: number | string
  locationCode: string
  skuName: string
  warehouseSku: string
  productNumber: string
  number: string
  locationName: string
}

export interface positionInfo {
  id?: number
  warehouseId?: string | number
  locationName: string
  pickingOrder: string
  locationCode: string
  warehouseName?: string
  status?: number
  remark: string
}

export interface positionFormInfo {
  id?: number
  warehouseId?: number | string
  locationName: string
  pickingOrder: string
  locationCode: string
  warehouseName: string
  remark: string
  status: number
}

interface WarehouseWarningData {
  id: number
  factoryId: number
  warehouseId: number
  warehouseName: string
  warehouseLocationId: number
  locationName: string
  warehouseSku: string
  skuName: string
  unit: string
  occupyInventory: number
  freezeInventory: number
  inventory: number
  upperLimit: number
  floorLimit: number
  productNumber: string
  itemSort: number
  dataVersion: number
  status: number
  createTime: string
  updateTime: string
}

export function getFactoryLocation(data: factoryWarehouseInfo) {
  return axios.post<never, BasePaginationData<positionInfo>>(
    'factoryWarehouseLocation/list_page',
    data,
  )
}
export function exportWarehouseInfo(data: ExportFactoryWarehouseInfo) {
  return axios.post<never, BasePaginationData<positionInfo>>(
    'factoryWarehouseInventory/inventory',
    data,
  )
}

export function getFactoryWarehouseInfo(data: factoryWarehouseInfo) {
  return axios.post<never, BasePaginationData<warehouseInfo>>(
    'factoryWarehouseInfo/list_page',
    data,
  )
}

export function getWarehouseInventoryInfo(data: WarehouseInventory) {
  return axios.post<never, BasePaginationData<WarehouseWarning>>(
    'factoryWarehouseInventory/list_page',
    data,
  )
}

export function createWarehouseApi(data: warehouseInfo) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInfo/add',
    data,
  )
}

export function factoryLogWarehouseLog(id: number | string | undefined) {
  return axios.get<never, BaseRespData<LogListData[]>>(
    '/factoryLogWarehouse/get',
    { params: { id } },
  )
}

export function factoryWarehouseInfoPrint(data: PrintData) {
  return axios.post<never, BaseRespData<never[]>>(
    '/factoryWarehouseInfo/print',
    data,
  )
}

export function importWarehouseLocation(data: FormData) {
  return axios.post<never, BaseRespData<never[]>>(
    '/factoryWarehouseLocation/importWarehouseLocation',
    data,
  )
}

export function factoryWarehouseInventoryPrint(data: PrintData) {
  return axios.post<never, BaseRespData<never[]>>(
    '/factoryWarehouseInventory/print',
    data,
  )
}

export function createPositionApi(data: positionInfo) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseLocation/add',
    data,
  )
}

export function warehouseInfoGetAll() {
  return axios.get<never, BaseRespData<warehouseInfo[]>>(
    '/factoryWarehouseInfo/getAll',
  )
}

export function createWarehouseInventoryApi(data: WarehouseWarningData) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInventory/add',
    data,
  )
}

export function updateWarehouseApi(data: positionInfo | UpdateDefaulted) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInfo/update',
    data,
  )
}

export function updatePositionApi(data: positionInfo) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseLocation/update',
    data,
  )
}

export function updatePositionStatusApi(data: UpdateStatus) {
  return axios.get<never, BaseRespData<never>>(
    '/factoryWarehouseLocation/updateStatus',
    { params: data },
  )
}

export function updateWarehouseInventoryApi(data: WarehouseWarningData) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInventory/update',
    data,
  )
}

export function deleteWarehouseApi(ids: string) {
  return axios.get<never, BaseRespData<never>>('/factoryWarehouseInfo/delete', {
    params: { ids },
  })
}

export function deleteLocationApi(ids: string) {
  return axios.get<never, BaseRespData<never>>(
    '/factoryWarehouseLocation/delete',
    {
      params: { ids },
    },
  )
}

export function deleteWarehouseInventory(ids: string) {
  return axios.get<never, BaseRespData<never>>(
    '/factoryWarehouseInventory/delete',
    {
      params: { ids },
    },
  )
}

// 入库单

export function warehouseInRecordListPageApi(
  data: warehouseSearchForm,
  currentPage: number,
  pageSize: number,
) {
  return axios.post<never, BasePaginationData<InterWarehousePage>>(
    '/factory/warehouseInRecord/list_page',
    {
      ...data,
      currentPage,
      pageSize,
    },
  )
}
export function rejectInRecordApi({
  list,
  rejectReason,
}: {
  list: WarehouseParams[]
  rejectReason: string
}) {
  return axios.post<never, BaseRespData<never>>(
    'factory/warehouseInRecord/reject',
    {
      list,
      rejectReason,
    },
  )
}
export function addInRecordApi(form: InterWarehouseDetail) {
  return axios.post<never, BaseRespData<never>>(
    'factory/warehouseInRecord/add',
    {
      ...form,
    },
  )
}
export function exportOrder(ids: number[], status: string | number) {
  return axios.post<never, BaseRespData<never>>(
    'factory/warehouseInRecord/exportData',
    { ids: ids, status },
  )
}
export function updateInRecordApi(form: InterWarehouseDetail) {
  return axios.post<never, BaseRespData<never>>(
    'factory/warehouseInRecord/update',
    {
      ...form,
    },
  )
}
export function getWarehouseInRecordDetailApi(id: number | undefined) {
  return axios.get<never, BaseRespData<InterWarehouseDetail>>(
    'factory/warehouseInRecord/get',
    {
      params: {
        id,
      },
    },
  )
}
export function getBySkuApi(warehouseId: number | string, sku: string | null) {
  return axios.get<never, BaseRespData<InterskuList[]>>(
    'customProductItem/getBySku',
    {
      params: {
        warehouseId,
        sku,
      },
    },
  )
}
export function getByWareHouseIdAndCodeApi(
  wareHouseId: number | string | undefined,
  code: string | null,
) {
  return axios.get<never, BaseRespData<ILocation[]>>(
    'factoryWarehouseLocation/getByWareHouseIdAndCode',
    {
      params: {
        wareHouseId,
        code,
      },
    },
  )
}
export function getInRecordStatusTree() {
  return axios.get<never, BaseRespData<InterWarehouseTree[]>>(
    'factory/warehouseInRecord/status_tree',
  )
}

export function getWarehouseListApi() {
  return axios.get<never, BaseRespData<InterWarehouseList[]>>(
    'factoryWarehouseInfo/getAll',
  )
}
interface WarehouseParams {
  id?: number
  dataVersion?: number
}
export function auditOrderApi(url: string, data: WarehouseParams[]) {
  return axios.post(url, data)
}
export function deleteWarehouseInRecordApi(ids: string) {
  return axios.get<never, BaseRespData<never>>(
    'factory/warehouseInRecord/delete',
    {
      params: { ids },
    },
  )
}
export function getInRecordLogApi(inRecordId?: number) {
  return axios.get<never, BaseRespData<LogListData[]>>(
    `factory/warehouseInRecord/log/${inRecordId}`,
  )
}
// 出库单
export function getOutRecordStatusTree() {
  return axios.get<never, BaseRespData<InterWarehouseTree[]>>(
    'factory/warehouseOutRecord/status_tree',
  )
}
export function warehouseOutRecordListPage(
  data: warehouseSearchForm,
  currentPage: number,
  pageSize: number,
) {
  return axios.post<never, BasePaginationData<InterWarehousePage>>(
    'factory/warehouseOutRecord/list_page',
    {
      ...data,
      currentPage,
      pageSize,
    },
  )
}
export function deleteWarehouseOutRecordApi(ids: string) {
  return axios.get<never, BaseRespData<never>>(
    'factory/warehouseOutRecord/delete',
    {
      params: { ids },
    },
  )
}
